@@ -1,6 +1,6 @@
 package Catalyst::Plugin::ErrorCatcher::Email;
 BEGIN {
-  $Catalyst::Plugin::ErrorCatcher::Email::VERSION = '0.0.8.7';
+  $Catalyst::Plugin::ErrorCatcher::Email::VERSION = '0.0.8.8';
 }
 BEGIN {
   $Catalyst::Plugin::ErrorCatcher::Email::DIST = 'Catalyst-Plugin-ErrorCatcher';
@@ -103,16 +103,18 @@ sub _parse_tags {
     my $c       = shift;
     my $subject = shift;
 
+    my $first_frame = $c->_errorcatcher_first_frame || {};
+
     my %tag_of = (
         '%h' => sub{Sys::Hostname::hostname()||'UnknownHost'},
-        '%f' => sub{$c->_errorcatcher_first_frame->{file}||'UnknownFile'},
+        '%f' => sub{$first_frame->{file}||'UnknownFile'},
         '%F' => sub{
-            my $val=$c->_errorcatcher_first_frame->{file}||'UnknownFile';
+            my $val=$first_frame->{file}||'UnknownFile';
             # ideally replace with cross-platform directory separator
             return _munge_path($val);
         },
-        '%l' => sub{$c->_errorcatcher_first_frame->{line}||'UnknownLine'},
-        '%p' => sub{$c->_errorcatcher_first_frame->{pkg}||'UnknownPackage'},
+        '%l' => sub{$first_frame->{line}||'UnknownLine'},
+        '%p' => sub{$first_frame->{pkg}||'UnknownPackage'},
         '%V' => sub{$c->config->{version}||'UnknownVersion'},
         '%n' => sub{$c->config->{name}||'UnknownAppName'},
     );
@@ -176,7 +178,7 @@ Catalyst::Plugin::ErrorCatcher::Email - an email emitter for Catalyst::Plugin::E
 
 =head1 VERSION
 
-version 0.0.8.7
+version 0.0.8.8
 
 =head1 SYNOPSIS
 
